<!--
Please provide any additional description/context not captured in `CHANGELOG.md`
and indicate any other packages/projects this is relevant to, including their
associated issues and/or pull requests
-->

### Developer checklist

- [ ] Assigned a reviewer
- [ ] Indicated the level of changes to this package by affixing one of these labels:
  * major -- Major changes to the API that may break current workflows
  * minor -- Minor changes to the API that do not break current workflows
  * patch -- Patches and bugfixes for the current version that do not break current workflows
  * bumpless -- Changes to documentation, CI/CD pipelines, etc. that don't affect the software's version
- [ ] (If applicable) Added/updated documentation for these changes
- [ ] (If applicable) Added/updated tests for these changes
